import { ActivatedRoute } from '@angular/router';
import { ViewModelReloader } from './view-model-reloader';
import { ResourceBase, HateoasClient } from 'fancy-hateoas-client';
import * as i0 from "@angular/core";
/**
 * Base class for angular components which represent a view and are backed by a hateoas resource.
 */
export declare abstract class TypedViewBase<TViewModel extends ResourceBase> implements ViewModelReloader {
    /**
     * A subject which gets triggered each time a new view model was loaded.
     */
    private _viewModelLoadedSubject;
    /**
     * The url of the view model of this instance.
     */
    protected viewModelUrl: string | undefined;
    /**
     * The activated route service.
     */
    protected activatedRoute: ActivatedRoute;
    /**
     * The hateoas client.
     */
    protected hateoasClient: HateoasClient;
    /**
     * A public observable to be used to subscribe to the view model loaded subject.
     */
    viewModelLoaded$: import("rxjs").Observable<ResourceBase>;
    /**
     * The current view model.
     */
    viewModel: TViewModel | null;
    constructor();
    /**
     * Reloads the current view model.
     */
    reloadViewModel(): Promise<ResourceBase>;
    /**
     * A life cycle hook to use when the implementing class needs to know when a new view model is availalbe.
     */
    viewModelOnLoaded(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TypedViewBase<any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<TypedViewBase<any>, never, never, {}, {}, never, never, false, never>;
}
/**
 * Base class for angular components which represent a untyped view and are backed by a hateoas resource.
 */
export declare abstract class ViewBase extends TypedViewBase<ResourceBase> {
    static ɵfac: i0.ɵɵFactoryDeclaration<ViewBase, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ViewBase, never, never, {}, {}, never, never, false, never>;
}
